@@ -21,7 +21,7 @@ ERR__command_not_allowed = "Command not allowed. Please use one of " + str(ALLOW
 
 class DBPGInterface(DBInterface):
 
-    HOST_POOL = None
+    HOST_POOL = {}
     HOST_USER = None
 
     def __init__(self, config, host: str, port: int, db_name: str, username: str, password: str, is_jaaql_user: bool,
@@ -40,18 +40,20 @@ class DBPGInterface(DBInterface):
                 conn_str += " host=" + host
             else:
                 self.is_host_pool = True
-            self.is_host_pool = True
             if str(port) != "5432":
                 conn_str += " port=" + str(port)
 
             self.username = username
 
+            if db_name is None:
+                db_name = ""
+
             if self.is_host_pool:
-                if DBPGInterface.HOST_POOL is None:
-                    DBPGInterface.HOST_POOL = ConnectionPool(conn_str, min_size=PGCONN__min_conns, max_size=PGCONN__max_conns_jaaql_user,
-                                                             max_lifetime=60 * 30)
+                if db_name.lower() not in DBPGInterface.HOST_POOL:
+                    DBPGInterface.HOST_POOL[db_name.lower()] = ConnectionPool(conn_str, min_size=PGCONN__min_conns,
+                                                                              max_size=PGCONN__max_conns_jaaql_user, max_lifetime=60 * 30)
                     DBPGInterface.HOST_USER = self.username
-                self.pg_pool = DBPGInterface.HOST_POOL
+                self.pg_pool = DBPGInterface.HOST_POOL[db_name.lower()]
             else:
                 self.pg_pool = ConnectionPool(conn_str, min_size=1, max_size=5)
         except OperationalError as ex:
@@ -97,10 +99,10 @@ class DBPGInterface(DBInterface):
             try:
                 with conn.cursor() as cursor:
                     do_prepare = False
-                    # if DBPGInterface.HOST_USER != self.username and self.username != USERNAME__jaaql:
-                    #     do_prepare = True
-                    #     if not any([query.upper().startswith(ok_command) for ok_command in ALLOWABLE_COMMANDS]):
-                    #         raise HttpStatusException(ERR__command_not_allowed)
+                    if DBPGInterface.HOST_USER != self.username and self.username != USERNAME__jaaql:
+                        do_prepare = True
+                        if not any([query.upper().startswith(ok_command) for ok_command in ALLOWABLE_COMMANDS]):
+                            raise HttpStatusException(ERR__command_not_allowed)
 
                     if parameters is None or len(parameters.keys()) == 0:
                         cursor.execute(query, prepare=do_prepare)
@@ -111,7 +113,7 @@ class DBPGInterface(DBInterface):
                     else:
                         return [desc[0] for desc in cursor.description], cursor.fetchall()
             except OperationalError as ex:
-                if ex.sqlstate is None or ex.sqlstate.startswith("08"):
+                if ex.sqlstate.startswith("08"):
                     traceback.print_exc()
                     self.pg_pool.putconn(conn)
                     self.pg_pool.check()
