@@ -467,10 +467,9 @@ class JAAQLModel(BaseJAAQLModel):
         threading.Thread(target=self.exit_jaaql).start()
 
     def install(self, db_connection_string: str, superjaaql_password: str, password: str, install_key: str,
-                use_mfa: bool, allow_uninstall: bool, ip_address: str, response: JAAQLResponse, allow_persistence: bool = True):
+                use_mfa: bool, allow_uninstall: bool, ip_address: str, response: JAAQLResponse):
         if not use_mfa and self.force_mfa:
             raise HttpStatusException(ERR__mfa_must_be_enabled)
-
         if self.jaaql_lookup_connection is None:
             if allow_uninstall:
                 self.vault.insert_obj(VAULT_KEY__allow_jaaql_uninstall, True)
@@ -483,136 +482,101 @@ class JAAQLModel(BaseJAAQLModel):
 
             address, port, db, username, db_password = DBInterface.fracture_uri(db_connection_string)
 
-            jaaql_password = None
+            db_interface = create_interface(self.config, address, port, db, username, db_password)
+            conn = db_interface.get_conn()
+            db_interface.execute_script_file(conn, join(get_jaaql_root(), DIR__scripts, "install_1.sql"))
+            resp = db_interface.execute_query(conn, QUERY__setup_jaaql_role)
+            jaaql_password = resp[1][0][0]
+            db_interface.commit(conn)
+            db_interface.put_conn(conn)
+            db_interface.close()
+            self.jaaql_lookup_connection = create_interface(self.config, address, port, db, USERNAME__jaaql, jaaql_password)
 
-            try:
-                db_interface = create_interface(self.config, address, port, db, username, db_password)
-                conn = db_interface.get_conn()
-                db_interface.execute_script_file(conn, join(get_jaaql_root(), DIR__scripts, "install_1.sql"))
-                resp = db_interface.execute_query(conn, QUERY__setup_jaaql_role)
-                jaaql_password = resp[1][0][0]
-                db_interface.commit(conn)
-                db_interface.put_conn(conn)
-                db_interface.close()
-                self.jaaql_lookup_connection = create_interface(self.config, address, port, db, USERNAME__jaaql, jaaql_password)
-
-                conn = self.jaaql_lookup_connection.get_conn()
-                self.jaaql_lookup_connection.execute_script_file(conn, join(get_jaaql_root(), DIR__scripts, "install_2.sql"))
-                self.jaaql_lookup_connection.put_conn(conn)
-            except Exception as ex:
-                if not allow_persistence:
-                    raise ex
+            conn = self.jaaql_lookup_connection.get_conn()
+            self.jaaql_lookup_connection.execute_script_file(conn, join(get_jaaql_root(), DIR__scripts, "install_2.sql"))
+            self.jaaql_lookup_connection.put_conn(conn)
 
+            self.add_node({
+                KEY__node_name: NODE__host_node,
+                KEY__description: None,
+                KEY__port: port,
+                KEY__address: address,
+            }, self.jaaql_lookup_connection)
             self.vault.insert_obj(VAULT_KEY__jaaql_lookup_connection, db_connection_string)
-            if self.jaaql_lookup_connection is None:
-                self.jaaql_lookup_connection = create_interface(self.config, address, port, db, username, db_password)
+            self.add_database({KEY__node: NODE__host_node, KEY__database_name: DB__jaaql}, self.jaaql_lookup_connection)
 
-            try:
-                try:
-                    self.add_node({
-                        KEY__node_name: NODE__host_node,
-                        KEY__description: None,
-                        KEY__port: port,
-                        KEY__address: address,
-                    }, self.jaaql_lookup_connection)
-                    self.add_database({KEY__node: NODE__host_node, KEY__database_name: DB__jaaql}, self.jaaql_lookup_connection)
-                except:
-                    pass
+            user_id = self.create_user(self.jaaql_lookup_connection, USERNAME__jaaql, jaaql_password)
+            mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__jaaql, password, user_id, ip_address, use_mfa=use_mfa, response=response)
 
-                if jaaql_password is None:
-                    jaaql_password = db_password
-                    user_id = self.create_user(self.jaaql_lookup_connection, USERNAME__jaaql,
-                                               jaaql_password, attach_as=username,
-                                               precedence=PRECEDENCE__super_user)
-                else:
-                    user_id = self.create_user(self.jaaql_lookup_connection, USERNAME__jaaql, jaaql_password)
-
-                mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__jaaql, password, user_id, ip_address, use_mfa=use_mfa,
-                                        response=response)
+            self.add_configuration_authorization({
+                KEY__application: APPLICATION__manager,
+                KEY__configuration: CONFIGURATION__host,
+                KEY__role: USERNAME__jaaql
+            }, self.jaaql_lookup_connection)
+            self.add_configuration_authorization({
+                KEY__application: APPLICATION__console,
+                KEY__configuration: CONFIGURATION__host,
+                KEY__role: USERNAME__jaaql
+            }, self.jaaql_lookup_connection)
+            self.add_configuration_authorization({
+                KEY__application: APPLICATION__playground,
+                KEY__configuration: CONFIGURATION__host,
+                KEY__role: USERNAME__jaaql
+            }, self.jaaql_lookup_connection)
 
+            superjaaql_db_password = db_password
+            super_otp_uri = None
+            super_otp_qr = None
+            if superjaaql_password is not None:
+                # Because we are setting this user up as postgres, it has a role of every user. Therefore we set this
+                # precedence as higher to override them
+                super_user_id = self.create_user(self.jaaql_lookup_connection, USERNAME__superjaaql,
+                                                 superjaaql_db_password, attach_as=USERNAME__postgres,
+                                                 precedence=PRECEDENCE__super_user)
+                super_mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__superjaaql, superjaaql_password,
+                                              super_user_id, ip_address, use_mfa=use_mfa)
+                super_otp_uri = super_mfa[KEY__otp_uri]
+                super_otp_qr = super_mfa[KEY__otp_qr]
                 self.add_configuration_authorization({
                     KEY__application: APPLICATION__manager,
                     KEY__configuration: CONFIGURATION__host,
-                    KEY__role: USERNAME__jaaql
+                    KEY__role: USERNAME__postgres
                 }, self.jaaql_lookup_connection)
                 self.add_configuration_authorization({
                     KEY__application: APPLICATION__console,
                     KEY__configuration: CONFIGURATION__host,
-                    KEY__role: USERNAME__jaaql
+                    KEY__role: USERNAME__postgres
                 }, self.jaaql_lookup_connection)
                 self.add_configuration_authorization({
                     KEY__application: APPLICATION__playground,
                     KEY__configuration: CONFIGURATION__host,
-                    KEY__role: USERNAME__jaaql
+                    KEY__role: USERNAME__postgres
                 }, self.jaaql_lookup_connection)
 
-                superjaaql_db_password = db_password
-                super_otp_uri = None
-                super_otp_qr = None
-                if superjaaql_password is not None:
-                    # Because we are setting this user up as postgres, it has a role of every user. Therefore we set this
-                    # precedence as higher to override them
-                    super_user_id = self.create_user(self.jaaql_lookup_connection, USERNAME__superjaaql,
-                                                     superjaaql_db_password, attach_as=username,
-                                                     precedence=PRECEDENCE__super_user)
-                    super_mfa = self.sign_up_user(self.jaaql_lookup_connection, USERNAME__superjaaql, superjaaql_password,
-                                                  super_user_id, ip_address, use_mfa=use_mfa)
-                    super_otp_uri = super_mfa[KEY__otp_uri]
-                    super_otp_qr = super_mfa[KEY__otp_qr]
-                    self.add_configuration_authorization({
-                        KEY__application: APPLICATION__manager,
-                        KEY__configuration: CONFIGURATION__host,
-                        KEY__role: username
-                    }, self.jaaql_lookup_connection)
-                    self.add_configuration_authorization({
-                        KEY__application: APPLICATION__console,
-                        KEY__configuration: CONFIGURATION__host,
-                        KEY__role: username
-                    }, self.jaaql_lookup_connection)
-                    self.add_configuration_authorization({
-                        KEY__application: APPLICATION__playground,
-                        KEY__configuration: CONFIGURATION__host,
-                        KEY__role: username
-                    }, self.jaaql_lookup_connection)
-
-                base_url = self.url + SEPARATOR__dir + DIR__apps + SEPARATOR__dir
-                execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
-                                           {KEY__application_url: base_url + DIR__console,
-                                            KEY__application_name: APPLICATION__console})
-                execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
-                                           {KEY__application_url: base_url + DIR__manager,
-                                            KEY__application_name: APPLICATION__manager})
-                execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_setup_host,
-                                           {KEY__application: APPLICATION__manager})
-                execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
-                                           {KEY__application_url: base_url + DIR__playground,
-                                            KEY__application_name: APPLICATION__playground})
-                execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_setup_host,
-                                           {KEY__application: APPLICATION__playground})
-
-                print("Rebooting to allow JAAQL config to be shared among workers")
-                print("Executing with platform: " + platform.python_implementation())
-                threading.Thread(target=self.exit_jaaql).start()
-
-                return {
-                    KEY__jaaql_otp_uri: mfa[KEY__otp_uri],
-                    KEY__jaaql_otp_qr: mfa[KEY__otp_qr],
-                    KEY__superjaaql_otp_uri: super_otp_uri,
-                    KEY__superjaaql_otp_qr: super_otp_qr
-                }
-            except Exception as ex:
-                if not allow_persistence:
-                    raise ex
+            base_url = self.url + SEPARATOR__dir + DIR__apps + SEPARATOR__dir
+            execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
+                                       {KEY__application_url: base_url + DIR__console,
+                                        KEY__application_name: APPLICATION__console})
+            execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
+                                       {KEY__application_url: base_url + DIR__manager,
+                                        KEY__application_name: APPLICATION__manager})
+            execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_setup_host,
+                                       {KEY__application: APPLICATION__manager})
+            execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_set_url,
+                                       {KEY__application_url: base_url + DIR__playground,
+                                        KEY__application_name: APPLICATION__playground})
+            execute_supplied_statement(self.jaaql_lookup_connection, QUERY__application_setup_host,
+                                       {KEY__application: APPLICATION__playground})
 
             print("Rebooting to allow JAAQL config to be shared among workers")
             print("Executing with platform: " + platform.python_implementation())
             threading.Thread(target=self.exit_jaaql).start()
 
             return {
-                KEY__jaaql_otp_uri: "",
-                KEY__jaaql_otp_qr: "",
-                KEY__superjaaql_otp_uri: "",
-                KEY__superjaaql_otp_qr: ""
+                KEY__jaaql_otp_uri: mfa[KEY__otp_uri],
+                KEY__jaaql_otp_qr: mfa[KEY__otp_qr],
+                KEY__superjaaql_otp_uri: super_otp_uri,
+                KEY__superjaaql_otp_qr: super_otp_qr
             }
         else:
             raise HttpStatusException(ERR__already_installed)
@@ -647,11 +611,21 @@ class JAAQLModel(BaseJAAQLModel):
 
         # TODO do databases. Link the used database auth with the log
 
+    def get_host_connection_for_db(self, user_id, database: str = DB__jaaql):
+        params = {
+            KEY__user_id: user_id,
+            KEY__node: NODE__host_node
+        }
+        auth = execute_supplied_statement_singleton(self.jaaql_lookup_connection, QUERY__role_connection_sel, params,
+                                                    as_objects=True, decrypt_columns=[KEY__username, KEY__password],
+                                                    encryption_key=self.get_db_crypt_key())
+        return create_interface(self.config, auth[KEY__address], auth[KEY__port], database, auth[KEY__username], auth[KEY__password])
+
     def verify_jwt(self, jwt_token: str, ip_address: str, was_refresh: bool, profiler: Profiler, bypass: str = None) -> [DBInterface, str, str]:
         username = None
 
         if bypass is not None and bypass == self.local_access_key:
-            username = USERNAME__superjaaql if not os.environ.get("DB_CONNECTION_STRING") else USERNAME__jaaql
+            username = USERNAME__superjaaql
             user, _, ip_id, last_totp = self.verify_user(username, ip_address)
         else:
             decoded = crypt_utils.jwt_decode(self.vault.get_obj(VAULT_KEY__jwt_crypt_key), jwt_token, JWT_PURPOSE__oauth, was_refresh)
@@ -683,20 +657,8 @@ class JAAQLModel(BaseJAAQLModel):
                     raise HttpStatusException(ERR__new_ip, HTTPStatus.UNAUTHORIZED)
                 profiler.perform_profile("Verify ip")
 
-        params = {
-            KEY__user_id: user[KEY__id],
-            KEY__node: NODE__host_node
-        }
-        auth = execute_supplied_statement_singleton(self.jaaql_lookup_connection, QUERY__role_connection_sel, params,
-                                                    as_objects=True, decrypt_columns=[KEY__username, KEY__password],
-                                                    encryption_key=self.get_db_crypt_key())
-        profiler.perform_profile("Select auth")
-
-        iv = user[KEY__totp_iv]
-        interface = create_interface(self.config, auth[KEY__address], auth[KEY__port], DB__jaaql, auth[KEY__username], auth[KEY__password]
-                                     ), user[KEY__id], ip_id, iv, user[ATTR__password_hash], last_totp, username, user[KEY__is_public]
-        profiler.perform_profile("Interface creation")
-        return interface
+        hc = self.get_host_connection_for_db(user[KEY__id])
+        return hc, user[KEY__id], ip_id, user[KEY__totp_iv], user[ATTR__password_hash], last_totp, username, user[KEY__is_public]
 
     def add_application(self, inputs: dict, jaaql_connection: DBInterface, ip_address: str, user_id: str, response: JAAQLResponse):
         public_username = inputs.pop(KEY__public_username)
@@ -1764,10 +1726,7 @@ class JAAQLModel(BaseJAAQLModel):
 
         return ret
 
-    def obtain_connection(self, inputs: dict, jaaql_connection: DBInterface):
-        if isinstance(inputs, list):
-            return jaaql_connection, True
-
+    def obtain_connection(self, inputs: dict, jaaql_connection: DBInterface, user_id: str):
         was_connection_none = inputs.get(KEY__connection, None) is None
         connection = inputs.get(KEY__connection, None)
 
@@ -1775,7 +1734,10 @@ class JAAQLModel(BaseJAAQLModel):
         obj_key = self.vault.get_obj(VAULT_KEY__jwt_obj_crypt_key)
 
         if connection is None:
-            connection = jaaql_connection
+            if inputs.get(KEY__database) is not None and user_id is not None:
+                connection = self.get_host_connection_for_db(user_id, inputs[KEY__database])
+            else:
+                connection = jaaql_connection
         else:
             jwt_decoded = crypt_utils.jwt_decode(jwt_key, connection, JWT_PURPOSE__connection)
             if not jwt_decoded:
@@ -1798,10 +1760,11 @@ class JAAQLModel(BaseJAAQLModel):
         inputs[KEY_query] = QUERY__my_roles
         return self.submit(inputs, jaaql_connection)[RET__rows]
 
-    def submit(self, inputs: dict, jaaql_connection: DBInterface, force_transactional: bool = False):
-        connection, was_connection_none = self.obtain_connection(inputs, jaaql_connection)
+    def submit(self, inputs: dict, jaaql_connection: DBInterface, force_transactional: bool = False, user_id: str = None):
+        connection, was_connection_none = self.obtain_connection(inputs, jaaql_connection, user_id)
 
         if KEY__database in inputs:
+            was_connection_none = False
             inputs.pop(KEY__database)
 
         caught_ex = None
